{ pkgs, ... }:
{
	imports = [./desktop.nix];

	systemd.network.networks.wifi = {
		matchConfig = {
			Name = "wlan0";
			SSID = [
				"!HotoHo-v6"
			];
		};
		DHCP = "ipv4";
		networkConfig = {
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
		};
	};
	systemd.network.networks.wifi-v6 = {
		matchConfig = {
			Name = "wlan0";
			SSID = [
				"urbanForest-v6"
			];
		};
		networkConfig = {
			DNSSEC = false;
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
		};
	};
	systemd.network.networks.wifi-unsec = {
		matchConfig = {
			Name = "wlan0";
			SSID = [
				"wanderverein" # fake to keep
			#	"urbanForest"
			];
		};
		DHCP = "ipv4";
		networkConfig = {
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
			DNSSEC = false;
			DNS = [
				"2001:4860:4860::8888"
				"8.8.8.8"
			];
		};
		dhcpV4Config = {
			UseDomains = false;
			UseDNS = false;
		};
		dhcpV6Config = {
			UseDNS = false;
		};
		ipv6AcceptRAConfig = {
			UseDNS = false;
		};
	};
	systemd.network.networks.eth = {
		matchConfig.Name = "enp*";
		DHCP = "ipv4";
		networkConfig = {
			IPv6AcceptRA = true;
			IPv6PrivacyExtensions = true;
		};
	};

	programs.sway = {
		enable = true;
		wrapperFeatures = { gtk = true; };
		extraPackages = with pkgs; [
			alacritty
			swayidle
			swaylock-effects
			mako
			bemenu
			# - bar
			i3blocks
			acpi
			lm_sensors
			# - tools
			wl-clipboard
			wdisplays
			ponymix
			brightnessctl
			gammastep
			grim
			slurp
		];
	};
	location.provider = "geoclue2";

	xdg.portal.wlr = {
		enable = true;
		settings.screencast = {
			chooser_type = "simple";
			chooser_cmd = "${pkgs.slurp}/bin/slurp -f %o -or";
		};
	};

	# done my sway:
	#  security.pam.services.swaylock = {};
	#  hardware.opengl.enable = true;
	#  fonts.enableDefaultFonts = true;
	#  programs.dconf.enable = true; # gtk theme

	# services.acpid.enable = true;
}
