{pkgs, lib, ...}:
{
	nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
		"ookla-speedtest"
	];
	home.packages = with pkgs; [
		(python3.withPackages(ps: with ps; [
			# ansible
			dnspython
			youtube-dl
			boto3 # aws-s3 support for ansible
			kubernetes #  is in ansible kubernetes.core module
			# dict_utils for an ansible filter_plugin
			setuptools
			deepmerge
			pip
			passlib # bcrypt
		]))
		ansible
		killall
		tree
		htop
		mosh
		git
		pre-commit
		git-lfs
		git-crypt
		git-annex
		ghorg
		tig
		tea
		glab
		figlet
		grml-zsh-config
		tmux
		w3m
		#neovim
		wget
		xh
		minio-client
		liboping # fix it
		mtr
		ookla-speedtest
		colordiff
		direnv
		pure-prompt
		#vimPlugins.nvim-lspconfig
		#vimPlugins.nerdtree
		go gcc libcap
		gopls
		cargo
		yarn
		pwgen
		pass-wayland
		gotify-cli
		glow
		imagemagick
		ffmpeg
		# devOps
		terraform
		tflint
		kubectl
		kubernetes-helm
		helmfile
		k9s
		# nixopsUnstable
	];

	programs.zsh = {
		enable = true;
		enableAutosuggestions = true;
		# broken: enableSyntaxHighlighting = true;
		# grml and pure enabled ....
	};
	programs.starship = {
		enable = true;
		settings = {
			directory = {
				truncation_length = 0;
			};
		};
	};
	programs.atuin = {
		enable = true;
		settings = {
			search_mode = "fulltext";
		};
	};
	programs.direnv.enable = true;
	programs.gitui.enable = true;

	programs.neovim = {
		enable = true;
		extraConfig = ''
		syntax on
		set number relativenumber
		'';
		plugins = with pkgs.vimPlugins; [
			nvim-lspconfig
			airline
			Syntastic
			{
				plugin = nerdtree;
				config = "map <C-n> :NERDTreeToggle<CR>";
			}
		];
	};
}
